
[![PyPI](https://img.shields.io/pypi/v/bgpfu.svg?maxAge=60)](https://pypi.python.org/pypi/bgpfu)
[![PyPI](https://img.shields.io/pypi/pyversions/bgpfu.svg?maxAge=600)](https://pypi.python.org/pypi/bgpfu)
[![Tests](https://github.com/bgpfu/bgpfu/workflows/tests/badge.svg)](https://github.com/bgpfu/bgpfu)
[![Codecov](https://img.shields.io/codecov/c/github/bgpfu/bgpfu/master.svg?maxAge=60)](https://codecov.io/github/bgpfu/bgpfu)


# BGP FU

![BGPFU](/../gh-pages/images/BGP-FU-Logo-RGB-resized.png?raw=true)

BGP FU is a toolbelt to assist with the automatic creation of safe prefix-filters.

BGP FU can ingest data from various sources such as IRRs/RPKI/other, transpose those
according to your policy preferences, and generate partial router configurations.

The jinja2 templating language is used to describe vendor specific output.

## Contact

Join us on `irc.terahertz.net` in `#BGPFU`
